@@ -101,6 +101,9 @@ class Cell():
     def execute(self):
         # Execute this cell's content
 
+        if not self.content_type == "python":
+            return
+
         gcopy = global_vars.copy()
         lcopy = local_vars.copy()
 
@@ -338,6 +341,8 @@ class Graph:
 
             p = threading.Thread(target=cell.execute)
 
+            print(cell.content_type)
+
             if cell.content_type == "python":
                 p.start()
                 p.join()
@@ -913,6 +918,9 @@ def create_app(test_config=None):
         old_name = data['old_name'].strip()
         new_name = data['new_name'].strip()
 
+        if new_name in interpreter.graph.get_all_cells_edges()[0]:
+            return "false"
+
         interpreter.rename_cell(['edit_cell', old_name, new_name])
 
         return "true"
@@ -1039,5 +1047,25 @@ def create_app(test_config=None):
                 'content_types': content_types,
                 'links': links}
 
+    @app.route("/set_as_md/", methods=["POST"])
+    def set_as_md():
+        cell_name = request.get_json()['cell_name']
+        interpreter.graph.get_cell(cell_name).content_type = "markdown"
+
+        return "true"
+
+    @app.route("/set_as_py/", methods=["POST"])
+    def set_as_py():
+        cell_name = request.get_json()['cell_name']
+        interpreter.graph.get_cell(cell_name).content_type = "python"
+
+        return "true"
+
+    @app.route("/reset_graph/", methods=["POST"])
+    def reset_graph():
+        interpreter.reset_graph(False)
+        interpreter.create_cell(["create_cell", "root", "python", "n"])
+        return "true"
+
 
     return app
\ No newline at end of file
