@@ -27,7 +27,7 @@ $(window).load(function () {
                 }
                 num_cells = 0;
                 for(var i = 0; i < names.length; i++){
-                    create_cell($("iframe").contents(), names[i], contents[i]);
+                    create_cell($("iframe").contents(), names[i], contents[i], content_types[i]);
                 }
             }
         }
@@ -69,7 +69,7 @@ $("#file-input").change(function(e){
                     num_cells = 0;
 
                     for(var i = 0; i < names.length; i++){
-                        create_cell($("iframe").contents(), names[i], contents[i]);
+                        create_cell($("iframe").contents(), names[i], contents[i], content_types[i]);
                     }
 
                     $("#file-input").val(null);
@@ -158,7 +158,7 @@ $("iframe").load(function(){
                     url : '/create_cell/',
                     dataType: "text",
                     success: function (data) {
-                        create_cell(doc, data, "");
+                        create_cell(doc, data, "", "python");
                     }
                 });
                 break;
@@ -209,7 +209,7 @@ $("iframe").load(function(){
                         'content_type': ''}),
                     contentType: "application/json",
                     success: function (data) {
-                        create_cell(doc, data['cell_name'], data['content']);
+                        create_cell(doc, data['cell_name'], data['content'], data['content_type']);
                     }
                 });
         }
@@ -259,7 +259,6 @@ $("iframe").load(function(){
                 data: JSON.stringify({'cell_name': clicked_textarea}),
                 contentType: "application/json",
                 complete: function (s) {
-                    console.log(s['responseText']);
                     if(s['responseText'] == "warning"){
                         if(!confirm("Linking to a cell with output links can cause undesired recursion. Are you sure?")){
                             continue_with_link = false;
@@ -296,7 +295,6 @@ $("iframe").load(function(){
 
     doc.on("click", "h6", function(){
         var old_name = $(this).text();
-        console.log(old_name);
         var new_name = prompt("Rename cell: ");
         if(new_name.length < 1){
             alert("Please use a longer cell name");
@@ -325,8 +323,8 @@ $("iframe").load(function(){
                             'new_name': new_name}),
                         contentType: "application/json",
                         success: function (success) {
-                            if(success == "false"){
-                                alert("Couldn't rename cell " + right_clicked_cell);
+                            if(!success){
+                                alert("Couldn't rename cell \"" + old_name + "\" to \"" + new_name + "\", another cell already has this name");
                             }
                             else{
                                 h6.html(new_name);
@@ -343,7 +341,6 @@ $("iframe").load(function(){
 
     doc.on("input propertychange", 'textarea', function() {
         currentVal = $(this).val();
-        console.log(clicked_textarea + " " + currentVal);
         $.ajax({
             type : "POST",
             url : '/edit_cell/',
@@ -362,21 +359,17 @@ $("iframe").load(function(){
     });
 });
 
+$(document).on("click", ".shutdown", function(){
+    shutdown();
+})
+
 //Navbar stuff
 $(document).on("click", "a", function(){
     var attr = $(this).attr("action");
 
     switch(attr){
         case "shutdown":
-            if(confirm("This will close the connection. Are you sure?")){
-                $.ajax({
-                    type : "POST",
-                    url : '/shutdown/',
-                    complete: function (s) {
-                        alert("Connection has been closed");
-                    }
-                });
-            }
+            shutdown();
             break;
         case "run_all":
             $.ajax({
@@ -439,7 +432,7 @@ $(document).on("click", "a", function(){
                         'content_type': ''}),
                     contentType: "application/json",
                     success: function (data) {
-                        create_cell($("iframe").contents(), data['cell_name'], data['content']);
+                        create_cell($("iframe").contents(), data['cell_name'], data['content'], data['content_type']);
                     }
                 });
             }
@@ -447,6 +440,72 @@ $(document).on("click", "a", function(){
         case "load_graph":
             $('#file-input').trigger('click');
             break;
+        case "set_as_md":
+            if(clicked_textarea != ""){
+                $.ajax({
+                    type : "POST",
+                    url : '/set_as_md/',
+                    dataType: "json",
+                    data: JSON.stringify({'cell_name': clicked_textarea}),
+                    contentType: "application/json",
+                    success: function (data) {
+                        var ele = $("iframe").contents().find(".textarea_" + clicked_textarea).prev();
+                        ele.removeClass().addClass("highlightGreen");
+                    }
+                });
+            }
+            break;
+        case "set_as_py":
+            if(clicked_textarea != ""){
+                $.ajax({
+                    type : "POST",
+                    url : '/set_as_py/',
+                    dataType: "json",
+                    data: JSON.stringify({'cell_name': clicked_textarea}),
+                    contentType: "application/json",
+                    success: function (data) {
+                        var ele = $("iframe").contents().find(".textarea_" + clicked_textarea).prev();
+                        ele.removeClass().addClass("highlightBlue");
+                    }
+                });
+            }
+            break;
+        case "reset_graph":
+            if(confirm("Resetting the graph will destroy all cells and variables. Are you sure?")){
+                $.ajax({
+                    type : "POST",
+                    url : '/reset_graph/',
+                    complete: function (s) {
+                        alert("Graph has been reset. Tab will now reload.");
+                        location.reload();
+                    }
+                });
+            }
+            break;
+        case "reset_run_all":
+            if(confirm("Resetting the runtime will destroy all variables. Are you sure?")){
+                $.ajax({
+                    type : "POST",
+                    url : '/reset_runtime/',
+                    complete: function (s) {
+                        $.ajax({
+                            type : "POST",
+                            url : '/root_has_outputs/',
+                            complete: function (s) {
+                                if(s['responseText'] == "warning"){
+                                    if(confirm("The root node has no outward links. Code execution starts at root, so this may result in unintended consequences. Continue?")){
+                                        bfs_execute();
+                                    }
+                                }
+                                else{
+                                    bfs_execute();
+                                }
+                            }
+                        });
+                    }
+                });
+            }
+            break;
     }
 })
 
@@ -481,14 +540,29 @@ function bfs_execute(){
     });
 }
 
-function create_cell(doc, name, content){
+function create_cell(doc, name, content, contentType){
 
     if(num_cells == 0){
         pageX = 0;
         pageY = 0;
     }
 
-    doc.find("#scene").append('<div id="draggable" class="'.concat(name, '"><h6 class="label">' + name + '</h6><div class="draggable"><div class="highlightBlue"></div><textarea class="textarea_' + name + '" spellcheck="false">' + content + '</textarea></div></div>'))
+    var colorClass = "";
+    switch(contentType){
+        case "python":
+            colorClass = "Blue";
+            break;
+        case "markdown":
+            colorClass = "Green";
+            break;
+        case "root":
+            colorClass = "Root";
+            break;
+    }
+
+    //    var new_ele = '<div id="draggable" class="' + name + '"><h6 class="label">' + name + '</h6><div class="draggable"><div class="' + colorClass + '"</div><textarea class="textarea_' + name + '" spellcheck="false">' + content + '</textarea></div></div>'
+
+    doc.find("#scene").append('<div id="draggable" class="'.concat(name, '"><h6 class="label">' + name + '</h6><div class="draggable" style="border-radius: 5px;"><div class="highlight' + colorClass + '" style="border-radius: 5px;"></div><textarea class="textarea_' + name + '" spellcheck="false">' + content + '</textarea></div></div>'))
 
     doc.find(".".concat(name)).css("top", (Math.ceil(pageY / 30 )*30)-4 );
     doc.find(".".concat(name)).css("left", (Math.ceil(pageX / 30 )*30)-4 );
@@ -497,4 +571,17 @@ function create_cell(doc, name, content){
     doc.find(".".concat(name)).draggable({ snap: ".".concat(name), grid: [ 30, 30 ] });
 
     num_cells += 1;
+}
+
+function shutdown(){
+    if(confirm("This will close the connection. Are you sure?")){
+        $.ajax({
+            type : "POST",
+            url : '/shutdown/',
+            complete: function (s) {
+                alert("Connection has been closed");
+                $("#connected_p").text("Disconnected");
+            }
+        });
+    }
 }
\ No newline at end of file
